# nlptkl 📚

A simple Python library that lets you read bundled text files directly after installation.

## Installation
```bash
pip install nlptkl
```

## Usage

```python
import nlptkl

print(nlptkl.get_text("sample1.txt"))
```
